@@ -27,7 +27,7 @@ around 'BUILDARGS' => sub {
     my %args = @_;
 
     # random ID for this message
-    $args{id} ||= unpack 'H*', Crypt::OpenSSL::Random::random_pseudo_bytes(16);
+    $args{id} ||='_' . unpack 'H*', Crypt::OpenSSL::Random::random_pseudo_bytes(16);
 
     # IssueInstant in UTC
     my $dt = DateTime->now( time_zone => 'UTC' );
